@@ -1,4 +1,4 @@
-/* $Id: init.c,v 1.35 2005/04/27 14:50:24 bdejean Exp $ */
+/* $Id: init.c,v 1.36 2005/08/02 09:47:18 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -26,6 +26,7 @@
 #include <glibtop/sysdeps.h>
 #include <glibtop/open.h>
 #include <glibtop/parameter.h>
+#include <glibtop/init_hooks.h>
 
 #ifndef DEFAULT_PORT
 #define DEFAULT_PORT 42800
@@ -219,7 +220,7 @@ glibtop *
 glibtop_init_s (glibtop **server_ptr, unsigned long features, unsigned flags)
 {
 	glibtop *server;
-	glibtop_init_func_t *init_fkt;
+	const glibtop_init_func_t *init_fkt;
 
 	if (server_ptr == NULL)
 		return NULL;
