@@ -4,11 +4,12 @@
 #include <config.h>
 
 #include <glibtop.h>
+#include <glibtop/error.h>
 #include <glibtop/open.h>
 
 #include <glibtop/sysdeps.h>
 #include <glibtop/union.h>
-#include "libgtop-i18n.h"
+#include <glib/gi18n-lib.h>
 
 #include <glibtop/command.h>
 
