@@ -1,4 +1,4 @@
-/* $Id: read.c,v 1.20 2004/10/10 17:21:57 bdejean Exp $ */
+/* $Id: read.c,v 1.23 2005/06/06 12:33:42 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -23,7 +23,8 @@
 
 #include <config.h>
 #include <glibtop/read.h>
-#include "libgtop-i18n.h"
+#include <glibtop/error.h>
+#include <glib/gi18n-lib.h>
 
 
 /* Reads some data from server. */
