@@ -19,7 +19,6 @@
    Boston, MA 02111-1307, USA.
 */
 
-#include <config.h>
 #include <glibtop.h>
 #include <glibtop/union.h>
 #include <glibtop/sysdeps.h>
@@ -46,152 +45,138 @@ GLIBTOP_SUID_PROC_ARGS +
 GLIBTOP_SUID_PROC_MAP +
 GLIBTOP_SUID_NETLOAD +
 GLIBTOP_SUID_NETLIST +
-GLIBTOP_SUID_PROC_WD +
-GLIBTOP_SUID_PROC_AFFINITY +
 GLIBTOP_SUID_PPP;
 
-const _glibtop_init_func_t _glibtop_init_hook_s [] = {
+const glibtop_init_func_t _glibtop_init_hook_s [] = {
 #if !GLIBTOP_SUID_CPU
-	_glibtop_init_cpu_s,
+	glibtop_init_cpu_s,
 #endif
 #if !GLIBTOP_SUID_MEM
-	_glibtop_init_mem_s,
+	glibtop_init_mem_s,
 #endif
 #if !GLIBTOP_SUID_SWAP
-	_glibtop_init_swap_s,
+	glibtop_init_swap_s,
 #endif
 #if !GLIBTOP_SUID_UPTIME
-	_glibtop_init_uptime_s,
+	glibtop_init_uptime_s,
 #endif
 #if !GLIBTOP_SUID_LOADAVG
-	_glibtop_init_loadavg_s,
+	glibtop_init_loadavg_s,
 #endif
 #if !GLIBTOP_SUID_SHM_LIMITS
-	_glibtop_init_shm_limits_s,
+	glibtop_init_shm_limits_s,
 #endif
 #if !GLIBTOP_SUID_MSG_LIMITS
-	_glibtop_init_msg_limits_s,
+	glibtop_init_msg_limits_s,
 #endif
 #if !GLIBTOP_SUID_SEM_LIMITS
-	_glibtop_init_sem_limits_s,
+	glibtop_init_sem_limits_s,
 #endif
 #if !GLIBTOP_SUID_PROCLIST
-	_glibtop_init_proclist_s,
+	glibtop_init_proclist_s,
 #endif
 #if !GLIBTOP_SUID_PROC_STATE
-	_glibtop_init_proc_state_s,
+	glibtop_init_proc_state_s,
 #endif
 #if !GLIBTOP_SUID_PROC_UID
-	_glibtop_init_proc_uid_s,
+	glibtop_init_proc_uid_s,
 #endif
 #if !GLIBTOP_SUID_PROC_MEM
-	_glibtop_init_proc_mem_s,
+	glibtop_init_proc_mem_s,
 #endif
 #if !GLIBTOP_SUID_PROC_TIME
-	_glibtop_init_proc_time_s,
+	glibtop_init_proc_time_s,
 #endif
 #if !GLIBTOP_SUID_PROC_SIGNAL
-	_glibtop_init_proc_signal_s,
+	glibtop_init_proc_signal_s,
 #endif
 #if !GLIBTOP_SUID_PROC_KERNEL
-	_glibtop_init_proc_kernel_s,
+	glibtop_init_proc_kernel_s,
 #endif
 #if !GLIBTOP_SUID_PROC_SEGMENT
-	_glibtop_init_proc_segment_s,
+	glibtop_init_proc_segment_s,
 #endif
 #if !GLIBTOP_SUID_PROC_ARGS
-	_glibtop_init_proc_args_s,
+	glibtop_init_proc_args_s,
 #endif
 #if !GLIBTOP_SUID_PROC_MAP
-	_glibtop_init_proc_map_s,
+	glibtop_init_proc_map_s,
 #endif
 #if !GLIBTOP_SUID_NETLOAD
-	_glibtop_init_netload_s,
+	glibtop_init_netload_s,
 #endif
 #if !GLIBTOP_SUID_NETLIST
-	_glibtop_init_netlist_s,
-#endif
-#if !GLIBTOP_SUID_PROC_WD
-	_glibtop_init_proc_wd_s,
-#endif
-#if !GLIBTOP_SUID_PROC_AFFINITY
-	_glibtop_init_proc_affinity_s,
+	glibtop_init_netlist_s,
 #endif
 #if !GLIBTOP_SUID_PPP
-	_glibtop_init_ppp_s,
+	glibtop_init_ppp_s,
 #endif
 	NULL
 };
 
-const _glibtop_init_func_t _glibtop_init_hook_p [] = {
+const glibtop_init_func_t _glibtop_init_hook_p [] = {
 #if GLIBTOP_SUID_CPU
-	_glibtop_init_cpu_p,
+	glibtop_init_cpu_p,
 #endif
 #if GLIBTOP_SUID_MEM
-	_glibtop_init_mem_p,
+	glibtop_init_mem_p,
 #endif
 #if GLIBTOP_SUID_SWAP
-	_glibtop_init_swap_p,
+	glibtop_init_swap_p,
 #endif
 #if GLIBTOP_SUID_UPTIME
-	_glibtop_init_uptime_p,
+	glibtop_init_uptime_p,
 #endif
 #if GLIBTOP_SUID_LOADAVG
-	_glibtop_init_loadavg_p,
+	glibtop_init_loadavg_p,
 #endif
 #if GLIBTOP_SUID_SHM_LIMITS
-	_glibtop_init_shm_limits_p,
+	glibtop_init_shm_limits_p,
 #endif
 #if GLIBTOP_SUID_MSG_LIMITS
-	_glibtop_init_msg_limits_p,
+	glibtop_init_msg_limits_p,
 #endif
 #if GLIBTOP_SUID_SEM_LIMITS
-	_glibtop_init_sem_limits_p,
+	glibtop_init_sem_limits_p,
 #endif
 #if GLIBTOP_SUID_PROCLIST
-	_glibtop_init_proclist_p,
+	glibtop_init_proclist_p,
 #endif
 #if GLIBTOP_SUID_PROC_STATE
-	_glibtop_init_proc_state_p,
+	glibtop_init_proc_state_p,
 #endif
 #if GLIBTOP_SUID_PROC_UID
-	_glibtop_init_proc_uid_p,
+	glibtop_init_proc_uid_p,
 #endif
 #if GLIBTOP_SUID_PROC_MEM
-	_glibtop_init_proc_mem_p,
+	glibtop_init_proc_mem_p,
 #endif
 #if GLIBTOP_SUID_PROC_TIME
-	_glibtop_init_proc_time_p,
+	glibtop_init_proc_time_p,
 #endif
 #if GLIBTOP_SUID_PROC_SIGNAL
-	_glibtop_init_proc_signal_p,
+	glibtop_init_proc_signal_p,
 #endif
 #if GLIBTOP_SUID_PROC_KERNEL
-	_glibtop_init_proc_kernel_p,
+	glibtop_init_proc_kernel_p,
 #endif
 #if GLIBTOP_SUID_PROC_SEGMENT
-	_glibtop_init_proc_segment_p,
+	glibtop_init_proc_segment_p,
 #endif
 #if GLIBTOP_SUID_PROC_ARGS
-	_glibtop_init_proc_args_p,
+	glibtop_init_proc_args_p,
 #endif
 #if GLIBTOP_SUID_PROC_MAP
-	_glibtop_init_proc_map_p,
+	glibtop_init_proc_map_p,
 #endif
 #if GLIBTOP_SUID_NETLOAD
-	_glibtop_init_netload_p,
+	glibtop_init_netload_p,
 #endif
 #if GLIBTOP_SUID_NETLIST
-	_glibtop_init_netlist_p,
-#endif
-#if GLIBTOP_SUID_PROC_WD
-	_glibtop_init_proc_wd_p,
-#endif
-#if GLIBTOP_SUID_PROC_AFFINITY
-	_glibtop_init_proc_affinity_p,
+	glibtop_init_netlist_p,
 #endif
 #if GLIBTOP_SUID_PPP
-	_glibtop_init_ppp_p,
+	glibtop_init_ppp_p,
 #endif
 	NULL
 };
