@@ -1,4 +1,4 @@
-/* $Id: proclist.c,v 1.17 2003/10/20 15:20:05 hadess Exp $ */
+/* $Id: proclist.c,v 1.19 2004/07/18 20:33:56 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -61,12 +61,12 @@ glibtop_init_proclist_p (glibtop *server)
  * The calling function has to free the memory to which a pointer is returned.
  *
  * On error, NULL is returned and buf->flags is zero. */
- 
+
 /* !!! THIS FUNCTION RUNS SUID ROOT - CHANGE WITH CAUTION !!! */
 
 unsigned *
 glibtop_get_proclist_p (glibtop *server, glibtop_proclist *buf,
-			int64_t which, int64_t arg)
+			gint64 which, gint64 arg)
 {
 	unsigned count = 0, total = 0;
 	unsigned pids [BLOCK_COUNT], *pids_chain = NULL;
@@ -75,13 +75,13 @@ glibtop_get_proclist_p (glibtop *server, glibtop_proclist *buf,
 	int entry, max_elements, k;
 
 	glibtop_init_p (server, GLIBTOP_SYSDEPS_PROCLIST, 0);
-	
+
 	memset (buf, 0, sizeof (glibtop_proclist));
-	
+
 	for (entry = 0; entry < server->machine.proctable_entries;
 	     entry += ELEMENTS_PER_ENTRY)
 	{
-		/* !!! THE FOLLOWING CODE RUNS SUID ROOT - 
+		/* !!! THE FOLLOWING CODE RUNS SUID ROOT -
 		 *     CHANGE WITH CAUTION !!! */
 
 		glibtop_suid_enter (server);
@@ -91,9 +91,9 @@ glibtop_get_proclist_p (glibtop *server, glibtop_proclist *buf,
 			 ELEMENTS_PER_ENTRY, sizeof (struct tbl_procinfo));
 
 		glibtop_suid_leave (server);
-		
+
 		/* !!! END OF SUID ROOT PART !!! */
-		
+
 		for (k = 0; k < max_elements; k++)
 		{
 			/* Does this entry contain a real process? */
@@ -124,17 +124,17 @@ glibtop_get_proclist_p (glibtop *server, glibtop_proclist *buf,
 				pids_size = new_size;
 
 				pids_offset += BLOCK_COUNT;
-				
+
 				count = 0;
 			}
 
 			/* pids is now big enough to hold at least
 			 * one single pid. */
-		
+
 			pids [count++] = procinfo [k].pi_pid;
-			
+
 			total++;
-		}	
+		}
 	}
 
 	/* count is only zero if an error occured
@@ -146,15 +146,15 @@ glibtop_get_proclist_p (glibtop *server, glibtop_proclist *buf,
 	 * g_malloc () if `pids_chain' is NULL. We just calculate the
 	 * new size and copy `pids' to the beginning of the newly allocated
 	 * block. */
-	
+
 	new_size = pids_size + count * sizeof (unsigned);
-	
+
 	pids_chain = g_realloc (server, pids_chain, new_size);
-	
+
 	memcpy (pids_chain + pids_offset, pids, count * sizeof (unsigned));
-	
+
 	pids_size = new_size;
-	
+
 	pids_offset += BLOCK_COUNT;
 
 	/* Since everything is ok now, we can set buf->flags, fill in the
