@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: proctime.c,v 1.9 2003/10/19 16:55:46 carlos Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -34,43 +32,38 @@ static const unsigned long _glibtop_sysdeps_proc_time =
 
 /* Init function. */
 
-int
+void
 glibtop_init_proc_time_s (glibtop *server)
 {
-    server->sysdeps.proc_time = _glibtop_sysdeps_proc_time;
-
-    return 0;
+	server->sysdeps.proc_time = _glibtop_sysdeps_proc_time;
 }
 
 /* Provides detailed information about a process. */
 
-int
+void
 glibtop_get_proc_time_s (glibtop *server, glibtop_proc_time *buf,
 			 pid_t pid)
 {
-    struct prusage prusage;
-    int retval;
+	struct prusage prusage;
 
-    memset (buf, 0, sizeof (glibtop_proc_time));
+	memset (buf, 0, sizeof (glibtop_proc_time));
 
-    /* Don't do it for scheduler, we don't want to frighten our users */
+	/* Don't do it for scheduler, we don't want to frighten our users */
 
-    if (!pid)
-	return -GLIBTOP_ERROR_INVALID_ARGUMENT;
+	if(pid)
+	{
+		if (glibtop_get_proc_data_usage_s (server, &prusage, pid))
+			return;
 
-    retval = glibtop_get_proc_data_usage_s (server, &prusage, pid);
-    if (retval) return retval;
+		buf->start_time = prusage.pr_create.tv_sec;
 
-    buf->start_time = prusage.pr_create.tv_sec;
+		buf->rtime = prusage.pr_rtime.tv_sec * 1E+6 +
+			prusage.pr_rtime.tv_nsec / 1E+3;
+		buf->utime = prusage.pr_utime.tv_sec * 1E+6 +
+			prusage.pr_utime.tv_nsec / 1E+3;
+		buf->stime = prusage.pr_stime.tv_sec * 1E+6 +
+			prusage.pr_stime.tv_nsec / 1E+3;
+	}
 
-    buf->rtime = prusage.pr_rtime.tv_sec * 1E+6 +
-	prusage.pr_rtime.tv_nsec / 1E+3;
-    buf->utime = prusage.pr_utime.tv_sec * 1E+6 +
-	prusage.pr_utime.tv_nsec / 1E+3;
-    buf->stime = prusage.pr_stime.tv_sec * 1E+6 +
-	prusage.pr_stime.tv_nsec / 1E+3;
-
-    buf->flags = _glibtop_sysdeps_proc_time;
-
-    return 0;
+	buf->flags = _glibtop_sysdeps_proc_time;
 }
