@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: shm_limits.c,v 1.13 2003/10/19 16:55:49 carlos Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -30,20 +28,16 @@ static const unsigned long _glibtop_sysdeps_shm_limits = 0;
 
 /* Init function. */
 
-int
+void
 glibtop_init_shm_limits_s (glibtop *server)
 {
-    server->sysdeps.shm_limits = _glibtop_sysdeps_shm_limits;
-
-    return 0;
+	server->sysdeps.shm_limits = _glibtop_sysdeps_shm_limits;
 }
 
 /* Provides information about sysv ipc limits. */
 
-int
+void
 glibtop_get_shm_limits_s (glibtop *server, glibtop_shm_limits *buf)
 {
-    memset (buf, 0, sizeof (glibtop_shm_limits));
-
-    return 0;
+	memset (buf, 0, sizeof (glibtop_shm_limits));
 }
