@@ -1,4 +1,4 @@
-/* $Id: proclist.c,v 1.15 2004/03/09 23:02:06 hadess Exp $ */
+/* $Id: proclist.c,v 1.17 2004/07/18 20:33:56 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -39,7 +39,7 @@ static const unsigned long _glibtop_sysdeps_proclist =
 
 unsigned *
 glibtop_get_proclist_p (glibtop *server, glibtop_proclist *buf,
-			int64_t which, int64_t arg)
+			gint64 which, gint64 arg)
 {
 	register struct proc *pp;
 	register int i, nproc = 0;
@@ -50,7 +50,7 @@ glibtop_get_proclist_p (glibtop *server, glibtop_proclist *buf,
 
 	memset (buf, 0, sizeof (glibtop_proclist));
 
-	/* Read process table from kernel. */	
+	/* Read process table from kernel. */
 
 	_glibtop_read_proc_table (server);
 
